"use strict";
function _interopDefault(ex) {
  return ex && "object" == typeof ex && "default" in ex ? ex.default : ex;
}
Object.defineProperty(exports, "__esModule", { value: !0 });
var nodePath = _interopDefault(require("path")),
  sourceMap = require("source-map"),
  convert = _interopDefault(require("convert-source-map")),
  findRoot = _interopDefault(require("find-root")),
  memoize = _interopDefault(require("@emotion/memoize")),
  hashString = _interopDefault(require("@emotion/hash")),
  escapeRegexp = _interopDefault(require("escape-string-regexp")),
  serialize = require("@emotion/serialize"),
  helperModuleImports = require("@babel/helper-module-imports"),
  babelPluginMacros = require("babel-plugin-macros"),
  multilineCommentRegex = /\/\*[^!](.|[\r\n])*?\*\//g,
  lineCommentStart = /\/\//g,
  symbolRegex = /(\s*[;:{},]\s*)/g,
  countOccurences = function(str, substr) {
    return str.split(substr).length - 1;
  },
  reduceSubstr = function(substrs, join, predicate) {
    var length = substrs.length,
      res = substrs[0];
    if (1 === length) return res;
    for (var i = 1; i < length && !predicate(res); i++)
      res += join + substrs[i];
    return res;
  },
  stripLineComment = function(line) {
    return reduceSubstr(line.split(lineCommentStart), "//", function(str) {
      return (
        !str.endsWith(":") &&
        countOccurences(str, "'") % 2 == 0 &&
        countOccurences(str, '"') % 2 == 0 &&
        countOccurences(str, "(") === countOccurences(str, ")")
      );
    });
  },
  compressSymbols = function(code) {
    return code.split(symbolRegex).reduce(function(str, fragment, index) {
      return index % 2 == 0
        ? str + fragment
        : countOccurences(str, "'") % 2 == 0 &&
          countOccurences(str, '"') % 2 == 0
          ? str + fragment.trim()
          : str + fragment;
    }, "");
  },
  isLineComment = function(line) {
    return line.trim().startsWith("//");
  },
  linebreakRegex = /[\r\n]\s*/g,
  minify = function(code) {
    var newCode = code
      .replace(multilineCommentRegex, "\n")
      .split(linebreakRegex)
      .filter(function(line) {
        return 0 < line.length && !isLineComment(line);
      })
      .map(stripLineComment)
      .join(" ");
    return compressSymbols(newCode);
  };
function getExpressionsFromTemplateLiteral(node, t) {
  var raw = createRawStringFromTemplateLiteral(node);
  return replacePlaceholdersWithExpressions(
    minify(raw),
    node.expressions || [],
    t
  );
}
var interleave = function(strings, interpolations) {
  return interpolations.reduce(
    function(array, interp, i) {
      return array.concat([interp], strings[i + 1]);
    },
    [strings[0]]
  );
};
function getDynamicMatches(str) {
  for (
    var match, re = /xxx(\d+)xxx/gm, matches = [];
    null !== (match = re.exec(str));

  )
    null !== match &&
      matches.push({
        value: match[0],
        p1: parseInt(match[1], 10),
        index: match.index
      });
  return matches;
}
function replacePlaceholdersWithExpressions(str, expressions, t) {
  var matches = getDynamicMatches(str);
  if (0 === matches.length) return "" === str ? [] : [t.stringLiteral(str)];
  var strings = [],
    finalExpressions = [],
    cursor = 0;
  return (
    matches.forEach(function(_ref, i) {
      var value = _ref.value,
        p1 = _ref.p1,
        index = _ref.index,
        preMatch = str.substring(cursor, index);
      (cursor = cursor + preMatch.length + value.length),
        preMatch
          ? strings.push(t.stringLiteral(preMatch))
          : 0 === i && strings.push(t.stringLiteral("")),
        finalExpressions.push(expressions[p1]),
        i === matches.length - 1 &&
          strings.push(t.stringLiteral(str.substring(index + value.length)));
    }),
    interleave(strings, finalExpressions).filter(function(node) {
      return "" !== node.value;
    })
  );
}
function createRawStringFromTemplateLiteral(quasi) {
  var strs = quasi.quasis.map(function(x) {
    return x.value.cooked;
  });
  return strs
    .reduce(function(arr, str, i) {
      return (
        arr.push(str), i !== strs.length - 1 && arr.push("xxx" + i + "xxx"), arr
      );
    }, [])
    .join("")
    .trim();
}
function getLabel(identifierName, autoLabel, labelFormat, filename) {
  if (!identifierName || !autoLabel) return null;
  if (!labelFormat) return identifierName.trim();
  var parsedPath = nodePath.parse(filename),
    localFilename = parsedPath.name;
  return (
    "index" === localFilename &&
      (localFilename = nodePath.basename(parsedPath.dir)),
    (localFilename = localFilename.replace(".", "-")),
    labelFormat
      .replace(/\[local\]/gi, identifierName.trim())
      .replace(/\[filename\]/gi, localFilename)
  );
}
function getLabelFromPath(path, state, t) {
  return getLabel(
    getIdentifierName(path, t),
    void 0 !== state.opts.autoLabel && state.opts.autoLabel,
    state.opts.labelFormat,
    state.file.opts.filename
  );
}
function getDeclaratorName(path, t) {
  var parent = path.findParent(function(p) {
    return p.isVariableDeclarator();
  });
  return parent && t.isIdentifier(parent.node.id) ? parent.node.id.name : "";
}
function getIdentifierName(path, t) {
  var classOrClassPropertyParent;
  if (
    t.isObjectProperty(path.parentPath) &&
    !1 === path.parentPath.node.computed &&
    (t.isIdentifier(path.parentPath.node.key) ||
      t.isStringLiteral(path.parentPath.node.key))
  )
    return path.parentPath.node.key.name || path.parentPath.node.key.value;
  if (
    (path &&
      (classOrClassPropertyParent = path.findParent(function(p) {
        return t.isClassProperty(p) || t.isClass(p);
      })),
    classOrClassPropertyParent)
  ) {
    if (
      t.isClassProperty(classOrClassPropertyParent) &&
      !1 === classOrClassPropertyParent.node.computed &&
      t.isIdentifier(classOrClassPropertyParent.node.key)
    )
      return classOrClassPropertyParent.node.key.name;
    if (
      t.isClass(classOrClassPropertyParent) &&
      classOrClassPropertyParent.node.id
    )
      return t.isIdentifier(classOrClassPropertyParent.node.id)
        ? classOrClassPropertyParent.node.id.name
        : "";
  }
  var declaratorName = getDeclaratorName(path, t);
  return "_" === declaratorName.charAt(0) ? "" : declaratorName;
}
function getGeneratorOpts(file) {
  return file.opts.generatorOpts ? file.opts.generatorOpts : file.opts;
}
function makeSourceMapGenerator(file) {
  var generatorOpts = getGeneratorOpts(file),
    filename = generatorOpts.sourceFileName,
    generator = new sourceMap.SourceMapGenerator({
      file: filename,
      sourceRoot: generatorOpts.sourceRoot
    });
  return generator.setSourceContent(filename, file.code), generator;
}
function getSourceMap(offset, state) {
  var generator = makeSourceMapGenerator(state.file),
    generatorOpts = getGeneratorOpts(state.file);
  return generatorOpts.sourceFileName
    ? (generator.addMapping({
        generated: { line: 1, column: 0 },
        source: generatorOpts.sourceFileName,
        original: offset
      }),
      convert.fromObject(generator).toComment({ multiline: !0 }))
    : "";
}
var hashArray = function(arr) {
    return hashString(arr.join(""));
  },
  unsafeRequire = require,
  getPackageRootPath = memoize(function(filename) {
    return findRoot(filename);
  }),
  separator = new RegExp(escapeRegexp(nodePath.sep), "g"),
  normalizePath = function(path) {
    return nodePath.normalize(path).replace(separator, "/");
  };
function getTargetClassName(state, t) {
  void 0 === state.emotionTargetClassNameCount &&
    (state.emotionTargetClassNameCount = 0);
  var filename = state.file.opts.filename,
    moduleName = "",
    rootPath = filename;
  try {
    (rootPath = getPackageRootPath(filename)),
      (moduleName = unsafeRequire(rootPath + "/package.json").name);
  } catch (err) {}
  var finalPath =
      filename === rootPath ? "root" : filename.slice(rootPath.length),
    positionInFile = state.emotionTargetClassNameCount++,
    stuffToHash = [moduleName];
  return (
    finalPath
      ? stuffToHash.push(normalizePath(finalPath))
      : stuffToHash.push(state.file.code),
    "e" + hashArray(stuffToHash) + positionInFile
  );
}
function simplifyObject(node, t) {
  for (var finalString = "", i = 0; i < node.properties.length; i++) {
    var _ref,
      property = node.properties[i];
    if (
      !t.isObjectProperty(property) ||
      property.computed ||
      (!t.isIdentifier(property.key) && !t.isStringLiteral(property.key)) ||
      (!t.isStringLiteral(property.value) &&
        !t.isNumericLiteral(property.value) &&
        !t.isObjectExpression(property.value))
    )
      return node;
    var key = property.key.name || property.key.value;
    if ("styles" === key) return node;
    if (t.isObjectExpression(property.value)) {
      var simplifiedChild = simplifyObject(property.value, t);
      if (!t.isStringLiteral(simplifiedChild)) return node;
      finalString += key + "{" + simplifiedChild.value + "}";
    } else {
      var value = property.value.value;
      finalString += serialize.serializeStyles([
        ((_ref = {}), (_ref[key] = value), _ref)
      ]).styles;
    }
  }
  return t.stringLiteral(finalString);
}
var appendStringToExpressions = function(expressions, string, t) {
    return (
      string &&
        (t.isStringLiteral(expressions[expressions.length - 1])
          ? (expressions[expressions.length - 1].value += string)
          : expressions.push(t.stringLiteral(string))),
      expressions
    );
  },
  joinStringLiterals = function(expressions, t) {
    return expressions.reduce(function(finalExpressions, currentExpression, i) {
      return (
        t.isStringLiteral(currentExpression) &&
        t.isStringLiteral(finalExpressions[finalExpressions.length - 1])
          ? (finalExpressions[finalExpressions.length - 1].value +=
              currentExpression.value)
          : finalExpressions.push(currentExpression),
        finalExpressions
      );
    }, []);
  };
function createSourceMapConditional(t, production, development) {
  return t.conditionalExpression(
    t.binaryExpression(
      "===",
      t.memberExpression(
        t.memberExpression(t.identifier("process"), t.identifier("env")),
        t.identifier("NODE_ENV")
      ),
      t.stringLiteral("production")
    ),
    production,
    development
  );
}
var transformExpressionWithStyles = function(_ref) {
    var babel = _ref.babel,
      state = _ref.state,
      path = _ref.path,
      shouldLabel = _ref.shouldLabel,
      _ref$sourceMap = _ref.sourceMap,
      sourceMap$$1 = void 0 === _ref$sourceMap ? "" : _ref$sourceMap,
      t = babel.types;
    if (t.isTaggedTemplateExpression(path)) {
      var expressions = getExpressionsFromTemplateLiteral(path.node.quasi, t);
      state.emotionSourceMap &&
        void 0 !== path.node.quasi.loc &&
        (sourceMap$$1 = getSourceMap(path.node.quasi.loc.start, state)),
        path.replaceWith(t.callExpression(path.node.tag, expressions));
    }
    if (t.isCallExpression(path)) {
      var label = getLabelFromPath(path, state, t);
      label &&
        shouldLabel &&
        appendStringToExpressions(
          path.node.arguments,
          "label:" + label + ";",
          t
        );
      var isPure = !0;
      if (
        (path.get("arguments").forEach(function(node) {
          node.isPure() || (isPure = !1),
            t.isObjectExpression(node) &&
              node.replaceWith(simplifyObject(node.node, t));
        }),
        (path.node.arguments = joinStringLiterals(path.node.arguments, t)),
        state.emotionSourceMap &&
          !sourceMap$$1 &&
          void 0 !== path.node.loc &&
          (sourceMap$$1 = getSourceMap(path.node.loc.start, state)),
        1 === path.node.arguments.length &&
          t.isStringLiteral(path.node.arguments[0]))
      ) {
        var cssString = path.node.arguments[0].value,
          res = serialize.serializeStyles([cssString]),
          prodNode = t.objectExpression([
            t.objectProperty(t.identifier("name"), t.stringLiteral(res.name)),
            t.objectProperty(
              t.identifier("styles"),
              t.stringLiteral(res.styles)
            )
          ]),
          node = prodNode;
        if (sourceMap$$1) {
          var devNode = t.objectExpression([
            t.objectProperty(t.identifier("name"), t.stringLiteral(res.name)),
            t.objectProperty(
              t.identifier("styles"),
              t.stringLiteral(res.styles)
            ),
            t.objectProperty(t.identifier("map"), t.stringLiteral(sourceMap$$1))
          ]);
          node = createSourceMapConditional(t, prodNode, devNode);
        }
        return { node: node, isPure: !0 };
      }
      if (sourceMap$$1) {
        var lastIndex = path.node.arguments.length - 1,
          last = path.node.arguments[lastIndex],
          sourceMapConditional = createSourceMapConditional(
            t,
            t.stringLiteral(""),
            t.stringLiteral(sourceMap$$1)
          );
        t.isStringLiteral(last)
          ? (path.node.arguments[lastIndex] = t.binaryExpression(
              "+",
              last,
              sourceMapConditional
            ))
          : path.node.arguments.push(sourceMapConditional);
      }
      return { node: void 0, isPure: isPure };
    }
    return { node: void 0, isPure: !1 };
  },
  getStyledOptions = function(t, path, state) {
    var properties = [
        t.objectProperty(
          t.identifier("target"),
          t.stringLiteral(getTargetClassName(state, t))
        )
      ],
      label = getLabelFromPath(path, state, t);
    label &&
      properties.push(
        t.objectProperty(t.identifier("label"), t.stringLiteral(label))
      );
    var args = path.node.arguments,
      optionsArgument = 2 <= args.length ? args[1] : null;
    return (
      optionsArgument &&
        (t.isObjectExpression(optionsArgument)
          ? properties.unshift.apply(properties, optionsArgument.properties)
          : console.warn(
              "Second argument to a styled call is not an object, it's going to be removed."
            )),
      t.objectExpression(properties)
    );
  },
  createEmotionMacro = function(instancePath) {
    return babelPluginMacros.createMacro(function(_ref) {
      var references = _ref.references,
        state = _ref.state,
        babel = _ref.babel;
      _ref.isEmotionCall || (state.emotionSourceMap = !0);
      var t = babel.types;
      Object.keys(references).forEach(function(referenceKey) {
        var isPure = !0,
          runtimeNode = helperModuleImports.addNamed(
            state.file.path,
            referenceKey,
            instancePath
          );
        switch (referenceKey) {
          case "injectGlobal":
            isPure = !1;
          case "css":
          case "keyframes":
            references[referenceKey].reverse().forEach(function(reference) {
              var path = reference.parentPath;
              reference.replaceWith(t.cloneDeep(runtimeNode)),
                isPure && path.addComment("leading", "#__PURE__");
              var node = transformExpressionWithStyles({
                babel: babel,
                state: state,
                path: path,
                shouldLabel: !0
              }).node;
              node && (path.node.arguments[0] = node);
            });
            break;
          default:
            references[referenceKey].reverse().forEach(function(reference) {
              reference.replaceWith(t.cloneDeep(runtimeNode));
            });
        }
      });
    });
  },
  createStyledMacro = function(_ref) {
    var importPath = _ref.importPath,
      isWeb = _ref.isWeb;
    return babelPluginMacros.createMacro(function(_ref2) {
      var references = _ref2.references,
        state = _ref2.state,
        babel = _ref2.babel;
      _ref2.isEmotionCall || (state.emotionSourceMap = !0);
      var t = babel.types;
      if (references.default && references.default.length) {
        var styledIdentifier = helperModuleImports.addDefault(
          state.file.path,
          importPath,
          { nameHint: "styled" }
        );
        references.default.forEach(function(reference) {
          if (
            (t.isMemberExpression(reference.parent) &&
            !1 === reference.parent.computed &&
            96 < reference.parent.property.name.charCodeAt(0)
              ? reference.parentPath.replaceWith(
                  t.callExpression(t.cloneDeep(styledIdentifier), [
                    t.stringLiteral(reference.parent.property.name)
                  ])
                )
              : reference.replaceWith(t.cloneDeep(styledIdentifier)),
            reference.parentPath && reference.parentPath.parentPath)
          ) {
            var styledCallPath = reference.parentPath.parentPath,
              node = transformExpressionWithStyles({
                path: styledCallPath,
                state: state,
                babel: babel,
                shouldLabel: !1
              }).node;
            node && isWeb && (styledCallPath.node.arguments[0] = node);
          }
          reference.addComment("leading", "#__PURE__"),
            t.isCallExpression(reference.parentPath) &&
              (reference.parentPath.node.arguments[1] = getStyledOptions(
                t,
                reference.parentPath,
                state
              ));
        });
      }
      Object.keys(references)
        .filter(function(x) {
          return "default" !== x;
        })
        .forEach(function(referenceKey) {
          var runtimeNode = helperModuleImports.addNamed(
            state.file.path,
            referenceKey,
            importPath
          );
          references[referenceKey].reverse().forEach(function(reference) {
            reference.replaceWith(t.cloneDeep(runtimeNode));
          });
        });
    });
  },
  transformCssCallExpression = function(_ref) {
    var babel = _ref.babel,
      state = _ref.state,
      path = _ref.path,
      sourceMap$$1 = _ref.sourceMap,
      _transformExpressionW = transformExpressionWithStyles({
        babel: babel,
        state: state,
        path: path,
        shouldLabel: !0,
        sourceMap: sourceMap$$1
      }),
      node = _transformExpressionW.node,
      isPure = _transformExpressionW.isPure;
    node
      ? (path.replaceWith(node), isPure && path.hoist())
      : path.addComment("leading", "#__PURE__");
  },
  cssMacro = babelPluginMacros.createMacro(function(_ref2) {
    var references = _ref2.references,
      state = _ref2.state,
      babel = _ref2.babel;
    _ref2.isEmotionCall || (state.emotionSourceMap = !0);
    var t = babel.types;
    references.default &&
      references.default.length &&
      references.default.reverse().forEach(function(reference) {
        state.cssIdentifier ||
          (state.cssIdentifier = helperModuleImports.addDefault(
            reference,
            "@emotion/css",
            { nameHint: "css" }
          )),
          reference.replaceWith(t.cloneDeep(state.cssIdentifier)),
          transformCssCallExpression({
            babel: babel,
            state: state,
            path: reference.parentPath
          });
      }),
      Object.keys(references)
        .filter(function(x) {
          return "default" !== x;
        })
        .forEach(function(referenceKey) {
          var runtimeNode = helperModuleImports.addNamed(
            state.file.path,
            referenceKey,
            "@emotion/css",
            { nameHint: referenceKey }
          );
          references[referenceKey].reverse().forEach(function(reference) {
            reference.replaceWith(t.cloneDeep(runtimeNode));
          });
        });
  }),
  webStyledMacro = createStyledMacro({
    importPath: "@emotion/styled-base",
    isWeb: !0
  }),
  nativeStyledMacro = createStyledMacro({
    importPath: "@emotion/native",
    isWeb: !1
  }),
  primitivesStyledMacro = createStyledMacro({
    importPath: "@emotion/primitives",
    isWeb: !1
  }),
  macros = {
    createEmotionMacro: createEmotionMacro,
    css: cssMacro,
    createStyledMacro: createStyledMacro
  },
  emotionCoreMacroThatsNotARealMacro = function(_ref) {
    var references = _ref.references,
      state = _ref.state,
      babel = _ref.babel;
    Object.keys(references).forEach(function(refKey) {
      "css" === refKey &&
        references[refKey].forEach(function(path) {
          transformCssCallExpression({
            babel: babel,
            state: state,
            path: path.parentPath
          });
        });
    });
  };
function getAbsolutePath(instancePath, rootPath) {
  return (
    "." === instancePath.charAt(0) && nodePath.resolve(rootPath, instancePath)
  );
}
function getInstancePathToCompare(instancePath, rootPath) {
  var absolutePath = getAbsolutePath(instancePath, rootPath);
  return !1 === absolutePath ? instancePath : absolutePath;
}
function index(babel) {
  var t = babel.types;
  return {
    name: "emotion",
    inherits: require("babel-plugin-syntax-jsx"),
    visitor: {
      ImportDeclaration: function(path, state) {
        var dirname =
          path.hub.file.opts.filename &&
          "unknown" !== path.hub.file.opts.filename
            ? nodePath.dirname(path.hub.file.opts.filename)
            : "";
        state.pluginMacros[path.node.source.value] ||
          -1 ===
            state.emotionInstancePaths.indexOf(
              getInstancePathToCompare(path.node.source.value, dirname)
            ) ||
          (state.pluginMacros[path.node.source.value] = createEmotionMacro(
            path.node.source.value
          ));
        var pluginMacros = state.pluginMacros;
        if (
          void 0 !== pluginMacros[path.node.source.value] &&
          !t.isImportNamespaceSpecifier(path.node.specifiers[0])
        ) {
          var imports = path.node.specifiers.map(function(s) {
              return {
                localName: s.local.name,
                importedName:
                  "ImportDefaultSpecifier" === s.type
                    ? "default"
                    : s.imported.name
              };
            }),
            shouldExit = !1,
            hasReferences = !1,
            referencePathsByImportName = imports.reduce(function(
              byName,
              _ref2
            ) {
              var importedName = _ref2.importedName,
                localName = _ref2.localName,
                binding = path.scope.getBinding(localName);
              return (
                binding
                  ? ((byName[importedName] = binding.referencePaths),
                    (hasReferences =
                      hasReferences || Boolean(byName[importedName].length)))
                  : (shouldExit = !0),
                byName
              );
            },
            {});
          hasReferences &&
            !shouldExit &&
            (state.file.scope.path.traverse({ Identifier: function() {} }),
            pluginMacros[path.node.source.value]({
              references: referencePathsByImportName,
              state: state,
              babel: babel,
              isBabelMacrosCall: !0,
              isEmotionCall: !0
            }),
            pluginMacros[path.node.source.value].keepImport || path.remove());
        }
      },
      Program: function(path, state) {
        if (
          ((state.emotionInstancePaths = (state.opts.instances || []).map(
            function(instancePath) {
              return getInstancePathToCompare(instancePath, process.cwd());
            }
          )),
          (state.pluginMacros = {
            "@emotion/css": cssMacro,
            "@emotion/styled": webStyledMacro,
            "@emotion/core": emotionCoreMacroThatsNotARealMacro,
            "@emotion/primitives": primitivesStyledMacro,
            "@emotion/native": nativeStyledMacro,
            emotion: createEmotionMacro("emotion")
          }),
          void 0 === state.opts.cssPropOptimization)
        ) {
          var _iterator = path.node.body,
            _isArray = Array.isArray(_iterator),
            _i = 0;
          for (
            _iterator = _isArray ? _iterator : _iterator[Symbol.iterator]();
            ;

          ) {
            var _ref3;
            if (_isArray) {
              if (_i >= _iterator.length) break;
              _ref3 = _iterator[_i++];
            } else {
              if ((_i = _iterator.next()).done) break;
              _ref3 = _i.value;
            }
            var node = _ref3;
            if (
              t.isImportDeclaration(node) &&
              "@emotion/core" === node.source.value &&
              node.specifiers.some(function(x) {
                return t.isImportSpecifier(x) && "jsx" === x.imported.name;
              })
            ) {
              state.transformCssProp = !0;
              break;
            }
          }
        } else state.transformCssProp = state.opts.cssPropOptimization;
        !1 === state.opts.sourceMap
          ? (state.emotionSourceMap = !1)
          : (state.emotionSourceMap = !0);
      },
      JSXAttribute: function(path, state) {
        if (
          "css" === path.node.name.name &&
          state.transformCssProp &&
          t.isJSXExpressionContainer(path.node.value) &&
          (t.isObjectExpression(path.node.value.expression) ||
            t.isArrayExpression(path.node.value.expression))
        ) {
          var expressionPath = path.get("value.expression");
          state.cssIdentifier ||
            (state.cssIdentifier = helperModuleImports.addDefault(
              path,
              "@emotion/css",
              { nameHint: "css" }
            ));
          var sourceMap$$1 =
            state.emotionSourceMap && void 0 !== path.node.loc
              ? getSourceMap(path.node.loc.start, state)
              : "";
          expressionPath.replaceWith(
            t.callExpression(
              t.cloneDeep(state.cssIdentifier),
              [path.node.value.expression].filter(Boolean)
            )
          ),
            transformCssCallExpression({
              babel: babel,
              state: state,
              path: expressionPath,
              sourceMap: sourceMap$$1
            });
        }
      },
      CallExpression: {
        exit: function(path, state) {
          try {
            if (
              path.node.callee &&
              path.node.callee.property &&
              "withComponent" === path.node.callee.property.name
            )
              switch (path.node.arguments.length) {
                case 1:
                case 2:
                  path.node.arguments[1] = getStyledOptions(t, path, state);
              }
          } catch (e) {
            throw path.buildCodeFrameError(e);
          }
        }
      }
    }
  };
}
(emotionCoreMacroThatsNotARealMacro.keepImport = !0),
  (exports.macros = macros),
  (exports.default = index);
